/**
 * Copyright (C) 2008 Ovea <dev@testatoo.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.testatoo.cartridge.input;

import org.junit.BeforeClass;
import org.junit.Test;
import org.testatoo.cartridge.WebTest;
import org.testatoo.cartridge.html4.By;
import org.testatoo.cartridge.html4.HtmlEvaluator;
import org.testatoo.core.ConditionChain;
import org.testatoo.core.EvaluatorHolder;
import org.testatoo.core.condition.TimerCondition;
import org.testatoo.core.input.KeyModifier;
import org.testatoo.core.input.Keyboard;

import static org.hamcrest.MatcherAssert.*;
import static org.hamcrest.Matchers.*;
import static org.testatoo.cartridge.html4.HtmlComponentFactory.*;
import static org.testatoo.core.input.Key.*;
import static org.testatoo.core.input.KeyModifier.*;

public class FullKeyboardTest extends WebTest {

    @BeforeClass
    public static void setUp() {
        HtmlEvaluator htmlEvaluator = (HtmlEvaluator) EvaluatorHolder.get();
        ConditionChain conditionChain = (ConditionChain) htmlEvaluator.getWaitingCondition();
        conditionChain.addCondition(new TimerCondition(200));

        page().open("AllKeysTest.html");
    }

    @Test
    public void can_test_CONTROL_key_modifier() {
        Keyboard.keyDown(KeyModifier.CONTROL);

        assertThat(findDiv(By.id("_Ctrl_a")).classname(), not(containsString("dirty")));
        Keyboard.type("a");
        assertThat(findDiv(By.id("_Ctrl_a")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_b")).classname(), not(containsString("dirty")));
        Keyboard.type("b");
        assertThat(findDiv(By.id("_Ctrl_b")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_c")).classname(), not(containsString("dirty")));
        Keyboard.type("c");
        assertThat(findDiv(By.id("_Ctrl_c")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_d")).classname(), not(containsString("dirty")));
        Keyboard.type("d");
        assertThat(findDiv(By.id("_Ctrl_d")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_e")).classname(), not(containsString("dirty")));
        Keyboard.type("e");
        assertThat(findDiv(By.id("_Ctrl_e")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f")).classname(), not(containsString("dirty")));
        Keyboard.type("f");
        assertThat(findDiv(By.id("_Ctrl_f")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_g")).classname(), not(containsString("dirty")));
        Keyboard.type("g");
        assertThat(findDiv(By.id("_Ctrl_g")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_h")).classname(), not(containsString("dirty")));
        Keyboard.type("h");
        assertThat(findDiv(By.id("_Ctrl_h")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_i")).classname(), not(containsString("dirty")));
        Keyboard.type("i");
        assertThat(findDiv(By.id("_Ctrl_i")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_j")).classname(), not(containsString("dirty")));
        Keyboard.type("j");
        assertThat(findDiv(By.id("_Ctrl_j")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_k")).classname(), not(containsString("dirty")));
        Keyboard.type("k");
        assertThat(findDiv(By.id("_Ctrl_k")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_l")).classname(), not(containsString("dirty")));
        Keyboard.type("l");
        assertThat(findDiv(By.id("_Ctrl_l")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_m")).classname(), not(containsString("dirty")));
        Keyboard.type("m");
        assertThat(findDiv(By.id("_Ctrl_m")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_n")).classname(), not(containsString("dirty")));
        Keyboard.type("n");
        assertThat(findDiv(By.id("_Ctrl_n")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_o")).classname(), not(containsString("dirty")));
        Keyboard.type("o");
        assertThat(findDiv(By.id("_Ctrl_o")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_p")).classname(), not(containsString("dirty")));
        Keyboard.type("p");
        assertThat(findDiv(By.id("_Ctrl_p")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_q")).classname(), not(containsString("dirty")));
        Keyboard.type("q");
        assertThat(findDiv(By.id("_Ctrl_q")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_r")).classname(), not(containsString("dirty")));
        Keyboard.type("r");
        assertThat(findDiv(By.id("_Ctrl_r")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_s")).classname(), not(containsString("dirty")));
        Keyboard.type("s");
        assertThat(findDiv(By.id("_Ctrl_s")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_t")).classname(), not(containsString("dirty")));
        Keyboard.type("t");
        assertThat(findDiv(By.id("_Ctrl_t")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_u")).classname(), not(containsString("dirty")));
        Keyboard.type("u");
        assertThat(findDiv(By.id("_Ctrl_u")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_v")).classname(), not(containsString("dirty")));
        Keyboard.type("v");
        assertThat(findDiv(By.id("_Ctrl_v")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_w")).classname(), not(containsString("dirty")));
        Keyboard.type("w");
        assertThat(findDiv(By.id("_Ctrl_w")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_x")).classname(), not(containsString("dirty")));
        Keyboard.type("x");
        assertThat(findDiv(By.id("_Ctrl_x")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_y")).classname(), not(containsString("dirty")));
        Keyboard.type("y");
        assertThat(findDiv(By.id("_Ctrl_y")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_z")).classname(), not(containsString("dirty")));
        Keyboard.type("z");
        assertThat(findDiv(By.id("_Ctrl_z")).classname(), containsString("dirty"));

        Keyboard.release();
    }

    @Test
    public void can_test_SHIFT_key_modifier() {
        Keyboard.keyDown(SHIFT);

        assertThat(findDiv(By.id("_Shift_a")).classname(), not(containsString("dirty")));
        Keyboard.type("a");
        assertThat(findDiv(By.id("_Shift_a")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_b")).classname(), not(containsString("dirty")));
        Keyboard.type("b");
        assertThat(findDiv(By.id("_Shift_b")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_c")).classname(), not(containsString("dirty")));
        Keyboard.type("c");
        assertThat(findDiv(By.id("_Shift_c")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_d")).classname(), not(containsString("dirty")));
        Keyboard.type("d");
        assertThat(findDiv(By.id("_Shift_d")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_e")).classname(), not(containsString("dirty")));
        Keyboard.type("e");
        assertThat(findDiv(By.id("_Shift_e")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f")).classname(), not(containsString("dirty")));
        Keyboard.type("f");
        assertThat(findDiv(By.id("_Shift_f")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_g")).classname(), not(containsString("dirty")));
        Keyboard.type("g");
        assertThat(findDiv(By.id("_Shift_g")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_h")).classname(), not(containsString("dirty")));
        Keyboard.type("h");
        assertThat(findDiv(By.id("_Shift_h")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_i")).classname(), not(containsString("dirty")));
        Keyboard.type("i");
        assertThat(findDiv(By.id("_Shift_i")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_j")).classname(), not(containsString("dirty")));
        Keyboard.type("j");
        assertThat(findDiv(By.id("_Shift_j")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_k")).classname(), not(containsString("dirty")));
        Keyboard.type("k");
        assertThat(findDiv(By.id("_Shift_k")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_l")).classname(), not(containsString("dirty")));
        Keyboard.type("l");
        assertThat(findDiv(By.id("_Shift_l")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_m")).classname(), not(containsString("dirty")));
        Keyboard.type("m");
        assertThat(findDiv(By.id("_Shift_m")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_n")).classname(), not(containsString("dirty")));
        Keyboard.type("n");
        assertThat(findDiv(By.id("_Shift_n")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_o")).classname(), not(containsString("dirty")));
        Keyboard.type("o");
        assertThat(findDiv(By.id("_Shift_o")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_p")).classname(), not(containsString("dirty")));
        Keyboard.type("p");
        assertThat(findDiv(By.id("_Shift_p")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_q")).classname(), not(containsString("dirty")));
        Keyboard.type("q");
        assertThat(findDiv(By.id("_Shift_q")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_r")).classname(), not(containsString("dirty")));
        Keyboard.type("r");
        assertThat(findDiv(By.id("_Shift_r")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_s")).classname(), not(containsString("dirty")));
        Keyboard.type("s");
        assertThat(findDiv(By.id("_Shift_s")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_t")).classname(), not(containsString("dirty")));
        Keyboard.type("t");
        assertThat(findDiv(By.id("_Shift_t")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_u")).classname(), not(containsString("dirty")));
        Keyboard.type("u");
        assertThat(findDiv(By.id("_Shift_u")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_v")).classname(), not(containsString("dirty")));
        Keyboard.type("v");
        assertThat(findDiv(By.id("_Shift_v")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_w")).classname(), not(containsString("dirty")));
        Keyboard.type("w");
        assertThat(findDiv(By.id("_Shift_w")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_x")).classname(), not(containsString("dirty")));
        Keyboard.type("x");
        assertThat(findDiv(By.id("_Shift_x")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_y")).classname(), not(containsString("dirty")));
        Keyboard.type("y");
        assertThat(findDiv(By.id("_Shift_y")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_z")).classname(), not(containsString("dirty")));
        Keyboard.type("z");
        assertThat(findDiv(By.id("_Shift_z")).classname(), containsString("dirty"));

        Keyboard.release();
    }

    @Test
    public void can_test_ALT_key_modifier() {
        Keyboard.keyDown(ALT);

        assertThat(findDiv(By.id("_Alt_a")).classname(), not(containsString("dirty")));
        Keyboard.type("a");
        assertThat(findDiv(By.id("_Alt_a")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_b")).classname(), not(containsString("dirty")));
        Keyboard.type("b");
        assertThat(findDiv(By.id("_Alt_b")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_c")).classname(), not(containsString("dirty")));
        Keyboard.type("c");
        assertThat(findDiv(By.id("_Alt_c")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_d")).classname(), not(containsString("dirty")));
        Keyboard.type("d");
        assertThat(findDiv(By.id("_Alt_d")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_e")).classname(), not(containsString("dirty")));
        Keyboard.type("e");
        assertThat(findDiv(By.id("_Alt_e")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f")).classname(), not(containsString("dirty")));
        Keyboard.type("f");
        assertThat(findDiv(By.id("_Alt_f")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_g")).classname(), not(containsString("dirty")));
        Keyboard.type("g");
        assertThat(findDiv(By.id("_Alt_g")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_h")).classname(), not(containsString("dirty")));
        Keyboard.type("h");
        assertThat(findDiv(By.id("_Alt_h")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_i")).classname(), not(containsString("dirty")));
        Keyboard.type("i");
        assertThat(findDiv(By.id("_Alt_i")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_j")).classname(), not(containsString("dirty")));
        Keyboard.type("j");
        assertThat(findDiv(By.id("_Alt_j")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_k")).classname(), not(containsString("dirty")));
        Keyboard.type("k");
        assertThat(findDiv(By.id("_Alt_k")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_l")).classname(), not(containsString("dirty")));
        Keyboard.type("l");
        assertThat(findDiv(By.id("_Alt_l")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_m")).classname(), not(containsString("dirty")));
        Keyboard.type("m");
        assertThat(findDiv(By.id("_Alt_m")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_n")).classname(), not(containsString("dirty")));
        Keyboard.type("n");
        assertThat(findDiv(By.id("_Alt_n")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_o")).classname(), not(containsString("dirty")));
        Keyboard.type("o");
        assertThat(findDiv(By.id("_Alt_o")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_p")).classname(), not(containsString("dirty")));
        Keyboard.type("p");
        assertThat(findDiv(By.id("_Alt_p")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_q")).classname(), not(containsString("dirty")));
        Keyboard.type("q");
        assertThat(findDiv(By.id("_Alt_q")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_r")).classname(), not(containsString("dirty")));
        Keyboard.type("r");
        assertThat(findDiv(By.id("_Alt_r")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_s")).classname(), not(containsString("dirty")));
        Keyboard.type("s");
        assertThat(findDiv(By.id("_Alt_s")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_t")).classname(), not(containsString("dirty")));
        Keyboard.type("t");
        assertThat(findDiv(By.id("_Alt_t")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_u")).classname(), not(containsString("dirty")));
        Keyboard.type("u");
        assertThat(findDiv(By.id("_Alt_u")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_v")).classname(), not(containsString("dirty")));
        Keyboard.type("v");
        assertThat(findDiv(By.id("_Alt_v")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_w")).classname(), not(containsString("dirty")));
        Keyboard.type("w");
        assertThat(findDiv(By.id("_Alt_w")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_x")).classname(), not(containsString("dirty")));
        Keyboard.type("x");
        assertThat(findDiv(By.id("_Alt_x")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_y")).classname(), not(containsString("dirty")));
        Keyboard.type("y");
        assertThat(findDiv(By.id("_Alt_y")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_z")).classname(), not(containsString("dirty")));
        Keyboard.type("z");
        assertThat(findDiv(By.id("_Alt_z")).classname(), containsString("dirty"));

        Keyboard.release();
    }

    @Test
    public void generalKeyTest() {
        assertThat(findDiv(By.id("_a")).classname(), not(containsString("dirty")));
        Keyboard.type("a");
        assertThat(findDiv(By.id("_a")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_b")).classname(), not(containsString("dirty")));
        Keyboard.type("b");
        assertThat(findDiv(By.id("_b")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_c")).classname(), not(containsString("dirty")));
        Keyboard.type("c");
        assertThat(findDiv(By.id("_c")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_d")).classname(), not(containsString("dirty")));
        Keyboard.type("d");
        assertThat(findDiv(By.id("_d")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_e")).classname(), not(containsString("dirty")));
        Keyboard.type("e");
        assertThat(findDiv(By.id("_e")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f")).classname(), not(containsString("dirty")));
        Keyboard.type("f");
        assertThat(findDiv(By.id("_f")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_g")).classname(), not(containsString("dirty")));
        Keyboard.type("g");
        assertThat(findDiv(By.id("_g")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_h")).classname(), not(containsString("dirty")));
        Keyboard.type("h");
        assertThat(findDiv(By.id("_h")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_i")).classname(), not(containsString("dirty")));
        Keyboard.type("i");
        assertThat(findDiv(By.id("_i")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_j")).classname(), not(containsString("dirty")));
        Keyboard.type("j");
        assertThat(findDiv(By.id("_j")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_k")).classname(), not(containsString("dirty")));
        Keyboard.type("k");
        assertThat(findDiv(By.id("_k")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_l")).classname(), not(containsString("dirty")));
        Keyboard.type("l");
        assertThat(findDiv(By.id("_l")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_m")).classname(), not(containsString("dirty")));
        Keyboard.type("m");
        assertThat(findDiv(By.id("_m")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_n")).classname(), not(containsString("dirty")));
        Keyboard.type("n");
        assertThat(findDiv(By.id("_n")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_o")).classname(), not(containsString("dirty")));
        Keyboard.type("o");
        assertThat(findDiv(By.id("_o")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_p")).classname(), not(containsString("dirty")));
        Keyboard.type("p");
        assertThat(findDiv(By.id("_p")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_q")).classname(), not(containsString("dirty")));
        Keyboard.type("q");
        assertThat(findDiv(By.id("_q")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_r")).classname(), not(containsString("dirty")));
        Keyboard.type("r");
        assertThat(findDiv(By.id("_r")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_s")).classname(), not(containsString("dirty")));
        Keyboard.type("s");
        assertThat(findDiv(By.id("_s")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_t")).classname(), not(containsString("dirty")));
        Keyboard.type("t");
        assertThat(findDiv(By.id("_t")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_u")).classname(), not(containsString("dirty")));
        Keyboard.type("u");
        assertThat(findDiv(By.id("_u")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_v")).classname(), not(containsString("dirty")));
        Keyboard.type("v");
        assertThat(findDiv(By.id("_v")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_w")).classname(), not(containsString("dirty")));
        Keyboard.type("w");
        assertThat(findDiv(By.id("_w")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_x")).classname(), not(containsString("dirty")));
        Keyboard.type("x");
        assertThat(findDiv(By.id("_x")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_y")).classname(), not(containsString("dirty")));
        Keyboard.type("y");
        assertThat(findDiv(By.id("_y")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_z")).classname(), not(containsString("dirty")));
        Keyboard.type("z");
        assertThat(findDiv(By.id("_z")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f1")).classname(), not(containsString("dirty")));
        Keyboard.press(F1);
        assertThat(findDiv(By.id("_f1")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f2")).classname(), not(containsString("dirty")));
        Keyboard.press(F2);
        assertThat(findDiv(By.id("_f2")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f3")).classname(), not(containsString("dirty")));
        Keyboard.press(F3);
        assertThat(findDiv(By.id("_f3")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f4")).classname(), not(containsString("dirty")));
        Keyboard.press(F4);
        assertThat(findDiv(By.id("_f4")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f5")).classname(), not(containsString("dirty")));
        Keyboard.press(F5);
        assertThat(findDiv(By.id("_f5")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f6")).classname(), not(containsString("dirty")));
        Keyboard.press(F6);
        assertThat(findDiv(By.id("_f6")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f7")).classname(), not(containsString("dirty")));
        Keyboard.press(F7);
        assertThat(findDiv(By.id("_f7")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f8")).classname(), not(containsString("dirty")));
        Keyboard.press(F8);
        assertThat(findDiv(By.id("_f8")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f9")).classname(), not(containsString("dirty")));
        Keyboard.press(F9);
        assertThat(findDiv(By.id("_f9")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f10")).classname(), not(containsString("dirty")));
        Keyboard.press(F10);
        assertThat(findDiv(By.id("_f10")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f11")).classname(), not(containsString("dirty")));
        Keyboard.press(F11);
        assertThat(findDiv(By.id("_f11")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_f12")).classname(), not(containsString("dirty")));
        Keyboard.press(F12);
        assertThat(findDiv(By.id("_f12")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_0")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD0);
        assertThat(findDiv(By.id("_0")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_1")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD1);
        assertThat(findDiv(By.id("_1")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_2")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD2);
        assertThat(findDiv(By.id("_2")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_3")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD3);
        assertThat(findDiv(By.id("_3")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_4")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD4);
        assertThat(findDiv(By.id("_4")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_5")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD5);
        assertThat(findDiv(By.id("_5")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_6")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD6);
        assertThat(findDiv(By.id("_6")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_7")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD7);
        assertThat(findDiv(By.id("_7")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_8")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD8);
        assertThat(findDiv(By.id("_8")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_9")).classname(), not(containsString("dirty")));
        Keyboard.press(NUMPAD9);
        assertThat(findDiv(By.id("_9")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_backspace")).classname(), not(containsString("dirty")));
        Keyboard.press(BACKSPACE);
        assertThat(findDiv(By.id("_backspace")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_tab")).classname(), not(containsString("dirty")));
        Keyboard.press(TAB);
        assertThat(findDiv(By.id("_tab")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_return")).classname(), not(containsString("dirty")));
        Keyboard.press(ENTER);
        assertThat(findDiv(By.id("_return")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_pause")).classname(), not(containsString("dirty")));
        Keyboard.press(PAUSE);
        assertThat(findDiv(By.id("_pause")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_esc")).classname(), not(containsString("dirty")));
        Keyboard.press(ESCAPE);
        assertThat(findDiv(By.id("_esc")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_space")).classname(), not(containsString("dirty")));
        Keyboard.press(SPACE);
        assertThat(findDiv(By.id("_space")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_pageup")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_UP);
        assertThat(findDiv(By.id("_pageup")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_pagedown")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_DOWN);
        assertThat(findDiv(By.id("_pagedown")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_end")).classname(), not(containsString("dirty")));
        Keyboard.press(END);
        assertThat(findDiv(By.id("_end")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_home")).classname(), not(containsString("dirty")));
        Keyboard.press(HOME);
        assertThat(findDiv(By.id("_home")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_left")).classname(), not(containsString("dirty")));
        Keyboard.press(LEFT_ARROW);
        assertThat(findDiv(By.id("_left")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_up")).classname(), not(containsString("dirty")));
        Keyboard.press(UP_ARROW);
        assertThat(findDiv(By.id("_up")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_right")).classname(), not(containsString("dirty")));
        Keyboard.press(RIGHT_ARROW);
        assertThat(findDiv(By.id("_right")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_down")).classname(), not(containsString("dirty")));
        Keyboard.press(DOWN_ARROW);
        assertThat(findDiv(By.id("_down")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_insert")).classname(), not(containsString("dirty")));
        Keyboard.press(INSERT);
        assertThat(findDiv(By.id("_insert")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_del")).classname(), not(containsString("dirty")));
        Keyboard.press(DELETE);
        assertThat(findDiv(By.id("_del")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_scroll")).classname(), not(containsString("dirty")));
        Keyboard.press(SCROLL_LOCK);
        assertThat(findDiv(By.id("_scroll")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_capslock")).classname(), not(containsString("dirty")));
        Keyboard.press(CAPS_LOCK);
        assertThat(findDiv(By.id("_capslock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_numlock")).classname(), not(containsString("dirty")));
        Keyboard.press(NUM_LOCK);
        assertThat(findDiv(By.id("_numlock")).classname(), containsString("dirty"));

//    ADD,
//    MULTIPLY,
//    SUBTRACT,
//    DIVIDE,
    }

    @Test
    public void can_test_CONTROL_Key() {
        Keyboard.keyDown(CONTROL);

        assertThat(findDiv(By.id("_Ctrl_esc")).classname(), not(containsString("dirty")));
        Keyboard.press(ESCAPE);
        assertThat(findDiv(By.id("_Ctrl_esc")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_tab")).classname(), not(containsString("dirty")));
        Keyboard.press(TAB);
        assertThat(findDiv(By.id("_Ctrl_tab")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_space")).classname(), not(containsString("dirty")));
        Keyboard.press(SPACE);
        assertThat(findDiv(By.id("_Ctrl_space")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_return")).classname(), not(containsString("dirty")));
        Keyboard.press(ENTER);
        assertThat(findDiv(By.id("_Ctrl_return")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_backspace")).classname(), not(containsString("dirty")));
        Keyboard.press(BACKSPACE);
        assertThat(findDiv(By.id("_Ctrl_backspace")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_scroll")).classname(), not(containsString("dirty")));
        Keyboard.press(SCROLL_LOCK);
        assertThat(findDiv(By.id("_Ctrl_scroll")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_capslock")).classname(), not(containsString("dirty")));
        Keyboard.press(CAPS_LOCK);
        assertThat(findDiv(By.id("_Ctrl_capslock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_numlock")).classname(), not(containsString("dirty")));
        Keyboard.press(NUM_LOCK);
        assertThat(findDiv(By.id("_Ctrl_numlock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_pause")).classname(), not(containsString("dirty")));
        Keyboard.press(PAUSE);
        assertThat(findDiv(By.id("_Ctrl_pause")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_insert")).classname(), not(containsString("dirty")));
        Keyboard.press(INSERT);
        assertThat(findDiv(By.id("_Ctrl_insert")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_home")).classname(), not(containsString("dirty")));
        Keyboard.press(HOME);
        assertThat(findDiv(By.id("_Ctrl_home")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_del")).classname(), not(containsString("dirty")));
        Keyboard.press(DELETE);
        assertThat(findDiv(By.id("_Ctrl_del")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_end")).classname(), not(containsString("dirty")));
        Keyboard.press(END);
        assertThat(findDiv(By.id("_Ctrl_end")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_pageup")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_UP);
        assertThat(findDiv(By.id("_Ctrl_pageup")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_pagedown")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_DOWN);
        assertThat(findDiv(By.id("_Ctrl_pagedown")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_left")).classname(), not(containsString("dirty")));
        Keyboard.press(LEFT_ARROW);
        assertThat(findDiv(By.id("_Ctrl_left")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_up")).classname(), not(containsString("dirty")));
        Keyboard.press(UP_ARROW);
        assertThat(findDiv(By.id("_Ctrl_up")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_right")).classname(), not(containsString("dirty")));
        Keyboard.press(RIGHT_ARROW);
        assertThat(findDiv(By.id("_Ctrl_right")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_down")).classname(), not(containsString("dirty")));
        Keyboard.press(DOWN_ARROW);
        assertThat(findDiv(By.id("_Ctrl_down")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f1")).classname(), not(containsString("dirty")));
        Keyboard.press(F1);
        assertThat(findDiv(By.id("_Ctrl_f1")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f2")).classname(), not(containsString("dirty")));
        Keyboard.press(F2);
        assertThat(findDiv(By.id("_Ctrl_f2")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f3")).classname(), not(containsString("dirty")));
        Keyboard.press(F3);
        assertThat(findDiv(By.id("_Ctrl_f3")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f4")).classname(), not(containsString("dirty")));
        Keyboard.press(F4);
        assertThat(findDiv(By.id("_Ctrl_f4")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f5")).classname(), not(containsString("dirty")));
        Keyboard.press(F5);
        assertThat(findDiv(By.id("_Ctrl_f5")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f6")).classname(), not(containsString("dirty")));
        Keyboard.press(F6);
        assertThat(findDiv(By.id("_Ctrl_f6")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f7")).classname(), not(containsString("dirty")));
        Keyboard.press(F7);
        assertThat(findDiv(By.id("_Ctrl_f7")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f8")).classname(), not(containsString("dirty")));
        Keyboard.press(F8);
        assertThat(findDiv(By.id("_Ctrl_f8")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f9")).classname(), not(containsString("dirty")));
        Keyboard.press(F9);
        assertThat(findDiv(By.id("_Ctrl_f9")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f10")).classname(), not(containsString("dirty")));
        Keyboard.press(F10);
        assertThat(findDiv(By.id("_Ctrl_f10")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f11")).classname(), not(containsString("dirty")));
        Keyboard.press(F11);
        assertThat(findDiv(By.id("_Ctrl_f11")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Ctrl_f12")).classname(), not(containsString("dirty")));
        Keyboard.press(F12);
        assertThat(findDiv(By.id("_Ctrl_f12")).classname(), containsString("dirty"));

        Keyboard.release();
    }

    @Test
    public void can_test_SHIFT_Key() {
        Keyboard.keyDown(SHIFT);

        assertThat(findDiv(By.id("_Shift_esc")).classname(), not(containsString("dirty")));
        Keyboard.press(ESCAPE);
        assertThat(findDiv(By.id("_Shift_esc")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_tab")).classname(), not(containsString("dirty")));
        Keyboard.press(TAB);
        assertThat(findDiv(By.id("_Shift_tab")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_space")).classname(), not(containsString("dirty")));
        Keyboard.press(SPACE);
        assertThat(findDiv(By.id("_Shift_space")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_return")).classname(), not(containsString("dirty")));
        Keyboard.press(ENTER);
        assertThat(findDiv(By.id("_Shift_return")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_backspace")).classname(), not(containsString("dirty")));
        Keyboard.press(BACKSPACE);
        assertThat(findDiv(By.id("_Shift_backspace")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_scroll")).classname(), not(containsString("dirty")));
        Keyboard.press(SCROLL_LOCK);
        assertThat(findDiv(By.id("_Shift_scroll")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_capslock")).classname(), not(containsString("dirty")));
        Keyboard.press(CAPS_LOCK);
        assertThat(findDiv(By.id("_Shift_capslock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_numlock")).classname(), not(containsString("dirty")));
        Keyboard.press(NUM_LOCK);
        assertThat(findDiv(By.id("_Shift_numlock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_pause")).classname(), not(containsString("dirty")));
        Keyboard.press(PAUSE);
        assertThat(findDiv(By.id("_Shift_pause")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_insert")).classname(), not(containsString("dirty")));
        Keyboard.press(INSERT);
        assertThat(findDiv(By.id("_Shift_insert")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_home")).classname(), not(containsString("dirty")));
        Keyboard.press(HOME);
        assertThat(findDiv(By.id("_Shift_home")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_del")).classname(), not(containsString("dirty")));
        Keyboard.press(DELETE);
        assertThat(findDiv(By.id("_Shift_del")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_end")).classname(), not(containsString("dirty")));
        Keyboard.press(END);
        assertThat(findDiv(By.id("_Shift_end")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_pageup")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_UP);
        assertThat(findDiv(By.id("_Shift_pageup")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_pagedown")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_DOWN);
        assertThat(findDiv(By.id("_Shift_pagedown")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_left")).classname(), not(containsString("dirty")));
        Keyboard.press(LEFT_ARROW);
        assertThat(findDiv(By.id("_Shift_left")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_up")).classname(), not(containsString("dirty")));
        Keyboard.press(UP_ARROW);
        assertThat(findDiv(By.id("_Shift_up")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_right")).classname(), not(containsString("dirty")));
        Keyboard.press(RIGHT_ARROW);
        assertThat(findDiv(By.id("_Shift_right")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_down")).classname(), not(containsString("dirty")));
        Keyboard.press(DOWN_ARROW);
        assertThat(findDiv(By.id("_Shift_down")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f1")).classname(), not(containsString("dirty")));
        Keyboard.press(F1);
        assertThat(findDiv(By.id("_Shift_f1")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f2")).classname(), not(containsString("dirty")));
        Keyboard.press(F2);
        assertThat(findDiv(By.id("_Shift_f2")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f3")).classname(), not(containsString("dirty")));
        Keyboard.press(F3);
        assertThat(findDiv(By.id("_Shift_f3")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f4")).classname(), not(containsString("dirty")));
        Keyboard.press(F4);
        assertThat(findDiv(By.id("_Shift_f4")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f5")).classname(), not(containsString("dirty")));
        Keyboard.press(F5);
        assertThat(findDiv(By.id("_Shift_f5")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f6")).classname(), not(containsString("dirty")));
        Keyboard.press(F6);
        assertThat(findDiv(By.id("_Shift_f6")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f7")).classname(), not(containsString("dirty")));
        Keyboard.press(F7);
        assertThat(findDiv(By.id("_Shift_f7")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f8")).classname(), not(containsString("dirty")));
        Keyboard.press(F8);
        assertThat(findDiv(By.id("_Shift_f8")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f9")).classname(), not(containsString("dirty")));
        Keyboard.press(F9);
        assertThat(findDiv(By.id("_Shift_f9")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f10")).classname(), not(containsString("dirty")));
        Keyboard.press(F10);
        assertThat(findDiv(By.id("_Shift_f10")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f11")).classname(), not(containsString("dirty")));
        Keyboard.press(F11);
        assertThat(findDiv(By.id("_Shift_f11")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Shift_f12")).classname(), not(containsString("dirty")));
        Keyboard.press(F12);
        assertThat(findDiv(By.id("_Shift_f12")).classname(), containsString("dirty"));

        Keyboard.release();
    }

    @Test
    public void can_test_ALT_Key() {
        Keyboard.keyDown(ALT);

        assertThat(findDiv(By.id("_Alt_esc")).classname(), not(containsString("dirty")));
        Keyboard.press(ESCAPE);
        assertThat(findDiv(By.id("_Alt_esc")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_tab")).classname(), not(containsString("dirty")));
        Keyboard.press(TAB);
        assertThat(findDiv(By.id("_Alt_tab")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_space")).classname(), not(containsString("dirty")));
        Keyboard.press(SPACE);
        assertThat(findDiv(By.id("_Alt_space")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_return")).classname(), not(containsString("dirty")));
        Keyboard.press(ENTER);
        assertThat(findDiv(By.id("_Alt_return")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_backspace")).classname(), not(containsString("dirty")));
        Keyboard.press(BACKSPACE);
        assertThat(findDiv(By.id("_Alt_backspace")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_scroll")).classname(), not(containsString("dirty")));
        Keyboard.press(SCROLL_LOCK);
        assertThat(findDiv(By.id("_Alt_scroll")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_capslock")).classname(), not(containsString("dirty")));
        Keyboard.press(CAPS_LOCK);
        assertThat(findDiv(By.id("_Alt_capslock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_numlock")).classname(), not(containsString("dirty")));
        Keyboard.press(NUM_LOCK);
        assertThat(findDiv(By.id("_Alt_numlock")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_pause")).classname(), not(containsString("dirty")));
        Keyboard.press(PAUSE);
        assertThat(findDiv(By.id("_Alt_pause")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_insert")).classname(), not(containsString("dirty")));
        Keyboard.press(INSERT);
        assertThat(findDiv(By.id("_Alt_insert")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_home")).classname(), not(containsString("dirty")));
        Keyboard.press(HOME);
        assertThat(findDiv(By.id("_Alt_home")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_del")).classname(), not(containsString("dirty")));
        Keyboard.press(DELETE);
        assertThat(findDiv(By.id("_Alt_del")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_end")).classname(), not(containsString("dirty")));
        Keyboard.press(END);
        assertThat(findDiv(By.id("_Alt_end")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_pageup")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_UP);
        assertThat(findDiv(By.id("_Alt_pageup")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_pagedown")).classname(), not(containsString("dirty")));
        Keyboard.press(PAGE_DOWN);
        assertThat(findDiv(By.id("_Alt_pagedown")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_left")).classname(), not(containsString("dirty")));
        Keyboard.press(LEFT_ARROW);
        assertThat(findDiv(By.id("_Alt_left")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_up")).classname(), not(containsString("dirty")));
        Keyboard.press(UP_ARROW);
        assertThat(findDiv(By.id("_Alt_up")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_right")).classname(), not(containsString("dirty")));
        Keyboard.press(RIGHT_ARROW);
        assertThat(findDiv(By.id("_Alt_right")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_down")).classname(), not(containsString("dirty")));
        Keyboard.press(DOWN_ARROW);
        assertThat(findDiv(By.id("_Alt_down")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f1")).classname(), not(containsString("dirty")));
        Keyboard.press(F1);
        assertThat(findDiv(By.id("_Alt_f1")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f2")).classname(), not(containsString("dirty")));
        Keyboard.press(F2);
        assertThat(findDiv(By.id("_Alt_f2")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f3")).classname(), not(containsString("dirty")));
        Keyboard.press(F3);
        assertThat(findDiv(By.id("_Alt_f3")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f4")).classname(), not(containsString("dirty")));
        Keyboard.press(F4);
        assertThat(findDiv(By.id("_Alt_f4")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f5")).classname(), not(containsString("dirty")));
        Keyboard.press(F5);
        assertThat(findDiv(By.id("_Alt_f5")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f6")).classname(), not(containsString("dirty")));
        Keyboard.press(F6);
        assertThat(findDiv(By.id("_Alt_f6")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f7")).classname(), not(containsString("dirty")));
        Keyboard.press(F7);
        assertThat(findDiv(By.id("_Alt_f7")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f8")).classname(), not(containsString("dirty")));
        Keyboard.press(F8);
        assertThat(findDiv(By.id("_Alt_f8")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f9")).classname(), not(containsString("dirty")));
        Keyboard.press(F9);
        assertThat(findDiv(By.id("_Alt_f9")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f10")).classname(), not(containsString("dirty")));
        Keyboard.press(F10);
        assertThat(findDiv(By.id("_Alt_f10")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f11")).classname(), not(containsString("dirty")));
        Keyboard.press(F11);
        assertThat(findDiv(By.id("_Alt_f11")).classname(), containsString("dirty"));

        assertThat(findDiv(By.id("_Alt_f12")).classname(), not(containsString("dirty")));
        Keyboard.press(F12);
        assertThat(findDiv(By.id("_Alt_f12")).classname(), containsString("dirty"));

        Keyboard.release();
    }

}

